Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2032)

Unified Diff: content/renderer/media/audio_hardware.h

Issue 9655018: Make AudioParameters a class instead of a struct (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix copyright years Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/media/audio_device_thread.cc ('k') | content/renderer/media/audio_hardware.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/audio_hardware.h
diff --git a/content/renderer/media/audio_hardware.h b/content/renderer/media/audio_hardware.h
index 5a9f85a0d2c880c97474d3f0a3d5bd007d0bcba2..30c423305b2e13ce858966bb9baa650891988195 100644
--- a/content/renderer/media/audio_hardware.h
+++ b/content/renderer/media/audio_hardware.h
@@ -8,6 +8,7 @@
#include "base/basictypes.h"
#include "content/common/content_export.h"
+#include "media/base/channel_layout.h"
// Contains static methods to query hardware properties from the browser
// process. Values are cached to avoid unnecessary round trips, but the cache
@@ -16,11 +17,11 @@ namespace audio_hardware {
// Fetch the sample rate of the default audio output end point device.
// Must be called from RenderThreadImpl::current().
-CONTENT_EXPORT double GetOutputSampleRate();
+CONTENT_EXPORT int GetOutputSampleRate();
// Fetch the sample rate of the default audio input end point device.
// Must be called from RenderThreadImpl::current().
-CONTENT_EXPORT double GetInputSampleRate();
+CONTENT_EXPORT int GetInputSampleRate();
// Fetch the buffer size we use for the default output device.
// Must be called from RenderThreadImpl::current().
@@ -31,9 +32,9 @@ CONTENT_EXPORT size_t GetOutputBufferSize();
// conjunction with AUDIO_PCM_LINEAR.
CONTENT_EXPORT size_t GetHighLatencyOutputBufferSize(int sample_rate);
// Fetch the number of audio channels for the default input device.
// Must be called from RenderThreadImpl::current().
-CONTENT_EXPORT uint32 GetInputChannelCount();
+CONTENT_EXPORT ChannelLayout GetInputChannelLayout();
// Forces the next call to any of the Get functions to query the hardware
// and repopulate the cache.
« no previous file with comments | « content/renderer/media/audio_device_thread.cc ('k') | content/renderer/media/audio_hardware.cc » ('j') | no next file with comments »
@@ -31,9 +32,9 @@ CONTENT_EXPORT size_t GetOutputBufferSize();
// conjunction with AUDIO_PCM_LINEAR.
CONTENT_EXPORT size_t GetHighLatencyOutputBufferSize(int sample_rate);
-// Fetch the number of audio channels for the default input device.
+// Fetch the audio channel layout for the default input device.
// Must be called from RenderThreadImpl::current().

Powered by Google App Engine
This is Rietveld 408576698